summaryrefslogtreecommitdiff
path: root/src/theory/uf/theory_uf.cpp
diff options
context:
space:
mode:
authorAina Niemetz <aina.niemetz@gmail.com>2021-03-31 15:23:17 -0700
committerGitHub <noreply@github.com>2021-03-31 22:23:17 +0000
commita1466978fbc328507406d4a121dab4d1a1047e1d (patch)
tree12b40f161bb4d7a6ee40c20c78a15d6cda3c1995 /src/theory/uf/theory_uf.cpp
parentf9a9af855fb65804ff0b36e764ccd9d0fa9f87f8 (diff)
Rename namespace CVC4 to CVC5. (#6249)
Diffstat (limited to 'src/theory/uf/theory_uf.cpp')
-rw-r--r--src/theory/uf/theory_uf.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/theory/uf/theory_uf.cpp b/src/theory/uf/theory_uf.cpp
index aaa9d60f0..29bb6ba7d 100644
--- a/src/theory/uf/theory_uf.cpp
+++ b/src/theory/uf/theory_uf.cpp
@@ -35,7 +35,7 @@
using namespace std;
-namespace CVC4 {
+namespace CVC5 {
namespace theory {
namespace uf {
@@ -691,6 +691,6 @@ bool TheoryUF::isHigherOrderType(TypeNode tn)
return ret;
}
-} /* namespace CVC4::theory::uf */
-} /* namespace CVC4::theory */
-} /* namespace CVC4 */
+} // namespace uf
+} // namespace theory
+} // namespace CVC5
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback